VirtualBox konuğu eklemesinde bulunmadan VirtualBox konuğundaki ekran çözünürlüğünü artırmak?


2

VirtualBox konuk eklemeleri yüklenmeden, yalnızca ekran çözünürlüğü 640x480'dir:

$ xrandr
xrandr: Failed to get size of gamma for output default
Screen 0: minimum 640 x 480, current 640 x 480, maximum 640 x 480
default connected primary 640x480+0+0 0mm x 0mm
   640x480       73.00* 

Örneğin, çözünürlük 1280x1024'e nasıl ayarlanabilir? Hiçbir VirtualBox konuk ilavesi gerekli olmamalıdır.

Konuk bir Fedora sistemidir.

Tam olarak hiçbir şey yapmadı bu Whonix makalesinde açıklandığı gibi bir Xorg config dosyası eklemeyi denedim .

Xrandr için yeni bir model almak için cvt kullanmak da işe yaramadı.

$ cvt 1280 1024
# 1280x1024 59.89 Hz (CVT 1.31M4) hsync: 63.67 kHz; pclk: 109.00 MHz
Modeline "1280x1024_60.00"  109.00  1280 1368 1496 1712  1024 1027 1034 1063 -hsync +vsync
$ xrandr --newmode "1280x1024_60.00"  109.00  1280 1368 1496 1712  1024 1027 1034 1063 -hsync +vsync
xrandr: Failed to get size of gamma for output default
$ xrandr
xrandr: Failed to get size of gamma for output default
Screen 0: minimum 640 x 480, current 640 x 480, maximum 640 x 480
default connected primary 640x480+0+0 0mm x 0mm
   640x480       73.00* 
  1280x1024_60.00 (0x1bd) 109.000MHz
        h: width  1280 start 1368 end 1496 total 1712 skew    0 clock  63.67KHz
        v: height 1024 start 1027 end 1034 total 1063           clock  59.89Hz
$ xrandr --addmode default 1280x1024_60.00
xrandr: Failed to get size of gamma for output default
$ xrandr --output default --mode 1280x1024_60.00
xrandr: Failed to get size of gamma for output default
xrandr: Configure crtc 0 failed

Bir VB kurulumunun önünde değilim ama hatırladığım kadarıyla, daha yüksek ekran çözünürlüğü istiyorsanız DKMS modülünü Misafir Eklemelerinden yüklemeniz gerekir.
— fpmurphy

Misafir ilavesi istemediğimi yazdım.
— Temel6 15.0515

Konuk ilavesi olmadan yapmak mümkün değildir.
— fpmurphy

Yanıtlar:


1

1) XOrg'u Durdurun

 stop REPLACEWITHNAMEOFXORGSERVICE

2) Konsolu aç

CTRL-ALT-F1

3) Varsayılan xorg.conf dosyasını oluşturun, mevcut değil

X -configure

4) xorg.conf.new dosyasını hareket ettirin, böylece sistem config dosyasını kullanır.

mv xorg.conf.new /etc/X11/xorg.conf

5) Yeniden başlat

reboot

6) xorg.conf dosyasını değiştirin, ekleyin

Section "Monitor"
...
 HorizSync 1.0 - 1000.0
 VertRefresh 1.0 - 1000.0
 Option "MinClock" "1.0"
 Option "MaxClock" "10000.0"
 Option "Primary" "True"
 Option "PreferredMode" "1920x1080"
...
EndSection

7) Yeniden başlat

reboot

8) Sistem Ayarları> Ekran> "Herhangi Bir -4: 3- Çözünürlük Seç"

9) Geniş ekranı etkinleştir

Host:VBoxManage setextradata "YOURGUEST" "CustomVideoMode1" "1920x1080x32"
Sitemizi kullandığınızda şunları okuyup anladığınızı kabul etmiş olursunuz: Çerez Politikası ve Gizlilik Politikası.
Licensed under cc by-sa 3.0 with attribution required.